###############################################################################
# Licensed Materials - Property of IBM
#
# 5724-W86 5724-X63
#
# (C) Copyright IBM Corp. 2003, 2012. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
###############################################################################

package UserConfig;

@ISA    = qw(Exporter);
@EXPORT = qw(postparser_config);

use strict;
use Exporter ();
use AudLog;

my @rules_no_split = (

	#-------------------------------------------------------------------------------
	# Modify/Add rules here
	#-------------------------------------------------------------------------------

	# {
	# RULE_TYPE               => 'FILE_SPLIT',
	# RULE_DESC               => 'Split for block 67109549 different time interval into different pif',
	# INPUT_FILE_DESCRIPTION  => ['^.*67109549.*-#-I\.pif$',],
	# COUNTERS_USED_TO_SPLIT_FILE => {
	# Proc_Type => '(.*)',
	# },
	# SPLIT_COUNTERS_ORDER    => [qw(Proc_Type)],
	# PRODUCE_PIF             => 'True',
	# PRODUCE_LIF             => 0,
	# },

	# {
	# RULE_TYPE => 'PIF_REMOVE',
	# RULE_DESC => 'Remove the input file for FILE_SPLIT block B67109549',
	# INPUT_FILE_DESCRIPTION => ['^.*67109549.*-#-I\.pif$'],
	# },

	{
		RULE_TYPE              => 'FILE_SPLIT',
		RULE_DESC              => 'Split different time interval into different pif',
		INPUT_FILE_DESCRIPTION => [
			'^.*6710.*-#-I\.pif$',
			#'^.*5033.*-#-I\.pif$',		#comment for alm00263988
			'^.*82833917.*-#-I\.pif$',    #v900r011
			'^.*82833961.*-#-I\.pif$',    #v900r011
			#### Added during v900r013
			'^.*(82834952|82863914|82863927|82863928|82863947|82863949|82863953).*-#-I\.pif$',
			'^.*(82834001|82834002|82834003|82863915|82863925|82863929|82833952).*-#-I\.pif$',
			'^.*82833951.*-#-I\.pif$',
		],
		COUNTERS_USED_TO_SPLIT_FILE => {
			START_TIME => '(.*)',
		},
		SPLIT_COUNTERS_ORDER        => [qw(START_TIME)],
		PRODUCE_PIF                 => 'True',
		PRODUCE_LIF                 => 0,
	},
	
	#This rule is added for #alm00263988
	{
		RULE_TYPE              => 'FILE_SPLIT',
		RULE_DESC              => 'Split different time interval into different pif',
		INPUT_FILE_DESCRIPTION => [
			'^.*5033.*-#-I\.pif$',
		],
		COUNTERS_USED_TO_SPLIT_FILE => {
			START_TIME => '(.*)',
		},
		SPLIT_COUNTERS_ORDER        => [qw(START_TIME)],
		REDUNDANT_DATA_COUNTERS     => ['RNC_ID'],
		PRODUCE_PIF                 => 'True',
		PRODUCE_LIF                 => 0,
	},

	{
		RULE_TYPE              => 'FILE_SPLIT',
		RULE_DESC              => 'Split block 67109394, 67109395, 67109549 into different pif according to Proc_Type',
		INPUT_FILE_DESCRIPTION => [
			#'^.*67109394.*-#-I-#-\d{2}:\d{2}-#-FS\.pif$',    #comment for alm00155493, added in v900r011
			#'^.*67109395.*-#-I-#-\d{2}:\d{2}-#-FS\.pif$',    #comment for alm00155493, added in v900r011
			'^.*67109549.*-#-I-#-\d{2}:\d{2}-#-FS\.pif$',    #r11, corrected during v900r011
		],
		COUNTERS_USED_TO_SPLIT_FILE => { Proc_Type => '(.*)', },
		SPLIT_COUNTERS_ORDER        => [qw(Proc_Type)],
		PRODUCE_PIF                 => 'True',
		PRODUCE_LIF                 => 0,
	},

	{
		RULE_TYPE              => 'PIF_REMOVE',
		RULE_DESC              => 'Remove the input file for FILE_SPLIT',
		INPUT_FILE_DESCRIPTION => [
			'^.*6710.*-#-I\.pif$',
			'^.*5033.*-#-I\.pif$',
			'^.*(82834952|82863914|82863927|82863928|82863947|82863949|82863953).*-#-I\.pif$',
			#'^.*67109394.*-#-I-#-\d{2}:\d{2}-#-FS\.pif$',    #comment for alm00155493, added in v900r011
			#'^.*67109395.*-#-I-#-\d{2}:\d{2}-#-FS\.pif$',    #comment for alm00155493, added in v900r011
		'^.*67109549.*-#-I-#-\d{2}:\d{2}-#-FS\.pif$',    #r11, corrected during v900r011
		],
	},

	{
		RULE_TYPE              => 'INFOINSERT',
		RULE_DESC              => 'Insert NodeB information into cell files',
		INPUT_FILE_DESCRIPTION => [
			'^.*67109365.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109366.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109367.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109368.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109369.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109370.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109371.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109372.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109373.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109374.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109375.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109376.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109377.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109378.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109379.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109380.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109381.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109382.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109383.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109384.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109385.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109386.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109387.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109388.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109389.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109390.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109391.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109392.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109393.*-#-I-#-.*-#-FS\.pif$', # r10
			'^.*67109413.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109471.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109474.*-#-I-#-.*-#-FS\.pif$', # r10
			'^.*67109505.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109508.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109509.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109510.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109523.*-#-I-#-.*-#-FS\.pif$', # r10
			'^.*67109545.*-#-I-#-.*-#-FS\.pif$', # r10
			'^.*67109549.*-#-I-#-\d{2}:\d{2}-#-FS-#-CELL-#-FS\.pif$', # corrected during v900r011
			#### Added during v900r013 release
			'^.*(82834952|82863914|82863927|82863928|82863947|82863949|82863953).*-#-I-#-.*-#-FS\.pif$',
		],
		HEADER_NAMES_USED_TO_ID_DATA_RECORD => [],
		NAMES_USED_TO_ID_DATA_RECORD        => ['CELL_ID'],
		INFO_FILE_DESCRIPTION               => ['Huawei_UTRAN_NodeB_Relationship.csv-#-I\.pif'],
		HEADER_NAMES_USED_TO_ID_INFORMATION => [],
		#NAMES_USED_TO_ID_INFORMATION        => ['Cell_Id'],
		NAMES_USED_TO_ID_INFORMATION        => ['CELL_ID'],
		OUTPUT_FILENAME_START               => 'II',
		DEFAULT_NULL_VALUE                  => 'UNKNOWN',
		ONLY_INSERT                         => ['NodeB_Id'],
		WRITE_DATA_LINE                     => 'True',
		REDUNDANT_DATA_COUNTERS             => ['Cell_Id'], #commented during v900r011
		PRODUCE_PIF                         => 'True',
	},
		
	{
		RULE_TYPE              => 'PERLIZE',
		RULE_DESCRIPTION       => 'Provide default NodeB_Id if not inserted previously',
		INPUT_FILE_DESCRIPTION => [
			'^.*67109365.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109366.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109367.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109368.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109369.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109370.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109371.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109372.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109373.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109374.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109375.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109376.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109377.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109378.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109379.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109380.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109381.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109382.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109383.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109384.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109385.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109386.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109387.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109388.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109389.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109390.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109391.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109392.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109393.*-#-I-#-.*-#-FS-#-S\.pif$', # r10
			'^.*67109413.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109471.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109474.*-#-I-#-.*-#-FS-#-S\.pif$', # r10
			'^.*67109505.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109508.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109509.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109510.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109523.*-#-I-#-.*-#-FS-#-S\.pif$', # r10
			'^.*67109545.*-#-I-#-.*-#-FS-#-S\.pif$', # r10
			'^.*67109549.*-#-I-#-\d{2}:\d{2}-#-FS-#-CELL-#-FS-#-S\.pif$', # corrected during v900r011
			#### Added during v900r013 release
			'^.*(82834952|82863914|82863927|82863928|82863947|82863949|82863953).*-#-I-#-.*-#-FS-#-S\.pif$',
		],
		FILENAME_SUFFIX  => 'PZ',
		DATA_COUNTERS_OP => sub {
			my $d_ref = shift;

			if ( not exists $d_ref->{NodeB_Id} or $d_ref->{NodeB_Id} eq '' ) {
				$d_ref->{NodeB_Id} = 'UNKNOWN';
			}
			
			return 0;
		},
		#PRODUCE_LIF => 'True',	

	},	
	
	#need to do PIF_REMOVE
	{
		RULE_TYPE              => 'PIF_REMOVE',
		RULE_DESC              => 'Remove II input files',
		INPUT_FILE_DESCRIPTION => [
			'^.*67109365.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109366.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109367.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109368.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109369.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109370.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109371.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109372.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109373.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109374.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109375.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109376.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109377.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109378.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109379.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109380.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109381.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109382.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109383.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109384.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109385.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109386.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109387.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109388.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109389.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109390.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109391.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109392.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109393.*-#-I-#-.*-#-FS\.pif$',    # r10
			'^.*67109413.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109471.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109474.*-#-I-#-.*-#-FS\.pif$',    # r10
			'^.*67109505.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109508.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109509.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109510.*-#-I-#-.*-#-FS\.pif$',
			'^.*67109523.*-#-I-#-.*-#-FS\.pif$',                         # r10
			'^.*67109545.*-#-I-#-.*-#-FS\.pif$',                         # r11
			#'^.*67109549.*-#-I-#-CELL-#-FS\.pif$', # r11
			'^.*67109549.*-#-I-#-\d{2}:\d{2}-#-FS-#-CELL-#-FS\.pif$',    # corrected during v900r011
			'^.*(82834952|82863914|82863927|82863928|82863947|82863949|82863953).*-#-FS.pif$',
			'^.*67109365.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109366.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109367.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109368.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109369.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109370.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109371.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109372.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109373.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109374.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109375.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109376.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109377.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109378.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109379.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109380.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109381.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109382.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109383.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109384.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109385.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109386.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109387.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109388.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109389.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109390.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109391.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109392.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109393.*-#-I-#-.*-#-FS-#-S\.pif$',    # r10
			'^.*67109413.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109471.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109474.*-#-I-#-.*-#-FS-#-S\.pif$',    # r10
			'^.*67109505.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109508.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109509.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109510.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109523.*-#-I-#-.*-#-FS-#-S\.pif$',                         # r10
			'^.*67109545.*-#-I-#-.*-#-FS-#-S\.pif$',                         # r11
			#'^.*67109549.*-#-I-#-CELL-#-FS\.pif$', # r11
			'^.*67109549.*-#-I-#-\d{2}:\d{2}-#-FS-#-CELL-#-FS-#-S\.pif$',    # corrected during v900r011
			'^.*(82834952|82863914|82863927|82863928|82863947|82863949|82863953).*-#-FS-#-S.pif$',
			
		],
	},

	
		
	{
		RULE_TYPE              => 'INFOINSERT',
		RULE_DESC              => 'Insert RNC_ID from 67109473',
		INPUT_FILE_DESCRIPTION => [
			'^.*50331648.*-#-I-#-.*-#-FS\.pif$',
			'^.*50331649.*-#-I-#-.*-#-FS\.pif$',
			'^.*50331650.*-#-I-#-.*-#-FS\.pif$',
			'^.*50331651.*-#-I-#-.*-#-FS\.pif$',
			'^.*50331652.*-#-I-#-.*-#-FS\.pif$',
			'^.*50331653.*-#-I-#-.*-#-FS\.pif$',
			#### Added during v900r013
			'^.*50331654.*-#-I-#-.*-#-FS\.pif$',
			'^.*50331655.*-#-I-#-.*-#-FS\.pif$',
			'^.*50331656.*-#-I-#-.*-#-FS\.pif$',
			'^.*50331657.*-#-I-#-.*-#-FS\.pif$',
			'^.*50331658.*-#-I-#-.*-#-FS\.pif$',
			'^.*50331659.*-#-I-#-.*-#-FS\.pif$',
		],
		HEADER_NAMES_USED_TO_ID_DATA_RECORD => [],
		NAMES_USED_TO_ID_DATA_RECORD        => ['NodeB_Id'],
		INFO_FILE_DESCRIPTION               => ['^.*67109473.*-#-I-#-.*-#-FS\.pif$'],
		HEADER_NAMES_USED_TO_ID_INFORMATION => [],
		NAMES_USED_TO_ID_INFORMATION        => ['NodeB_Map_RNC_Id'],
		OUTPUT_FILENAME_START               => 'II',
		ONLY_INSERT                         => ['RNC_ID'],
		WRITE_DATA_LINE                     => 'True',
		#DEFAULT_NULL_VALUE                  => 'UNKNOWN',
		REDUNDANT_DATA_COUNTERS             => ['NodeB_Map_RNC_Id'],
		PRODUCE_PIF                         => 'True',
		PRODUCE_LIF                         => '0',
	},

	{
		
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Joining PIF files after INFOINSERT to cater for missing INFO FILE.',
		INPUT_FILE_DESCRIPTION => [
			'^.*50331648(.*)-#-I-#-(.*)-#-FS\.pif$',
			'^.*50331648(.*)-#-I-#-(.*)-#-FS-#-S\.pif$',
		],
		OUTPUT_BLOCK_NAME                         => 'B50331648',
		OUTPUT_FILENAME_START                     => 'B50331648_JOIN',
		COUNTERS_TO_JOIN_ON                       => [qw(NodeB_Id Local_Cell_Id START_DATE START_TIME)],
		REDUNDANT_DATA_COUNTERS                   => [],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(FILENAME)],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => -1,
		PRODUCE_PIF                               => 'True',
	},			
	
	{
		
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Joining PIF files after INFOINSERT to cater for missing INFO FILE.',
		INPUT_FILE_DESCRIPTION => [
			'^.*50331649(.*)-#-I-#-(.*)-#-FS\.pif$',
			'^.*50331649(.*)-#-I-#-(.*)-#-FS-#-S\.pif$',
		],
		OUTPUT_BLOCK_NAME                         => 'B50331649',
		OUTPUT_FILENAME_START                     => 'B50331649_JOIN',
		COUNTERS_TO_JOIN_ON                       => [qw(NodeB_Id START_DATE START_TIME)],
		REDUNDANT_DATA_COUNTERS                   => [],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(FILENAME)],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => -1,
		PRODUCE_PIF                               => 'True',
	},
	
	{
		
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Joining PIF files after INFOINSERT to cater for missing INFO FILE.',
		INPUT_FILE_DESCRIPTION => [
			'^.*50331650(.*)-#-I-#-(.*)-#-FS\.pif$',
			'^.*50331650(.*)-#-I-#-(.*)-#-FS-#-S\.pif$',
		],
		OUTPUT_BLOCK_NAME                         => 'B50331650',
		OUTPUT_FILENAME_START                     => 'B50331650_JOIN',
		COUNTERS_TO_JOIN_ON                       => [qw(NodeB_Id Local_Cell_Id START_DATE START_TIME)],
		REDUNDANT_DATA_COUNTERS                   => [],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(FILENAME)],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => -1,
		PRODUCE_PIF                               => 'True',
	},			
	
	{
		
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Joining PIF files after INFOINSERT to cater for missing INFO FILE.',
		INPUT_FILE_DESCRIPTION => [
			'^.*50331651(.*)-#-I-#-(.*)-#-FS\.pif$',
			'^.*50331651(.*)-#-I-#-(.*)-#-FS-#-S\.pif$',
		],
		OUTPUT_BLOCK_NAME                         => 'B50331651',
		OUTPUT_FILENAME_START                     => 'B50331651_JOIN',
		COUNTERS_TO_JOIN_ON                       => [qw(NodeB_Id Local_Cell_Id START_DATE START_TIME)],
		REDUNDANT_DATA_COUNTERS                   => [],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(FILENAME)],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => -1,
		PRODUCE_PIF                               => 'True',
	},	
		
	{
		
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Joining PIF files after INFOINSERT to cater for missing INFO FILE.',
		INPUT_FILE_DESCRIPTION => [
			'^.*50331652(.*)-#-I-#-(.*)-#-FS\.pif$',
			'^.*50331652(.*)-#-I-#-(.*)-#-FS-#-S\.pif$',
		],
		OUTPUT_BLOCK_NAME                         => 'B50331652',
		OUTPUT_FILENAME_START                     => 'B50331652_JOIN',
		COUNTERS_TO_JOIN_ON                       => [qw(NodeB_Id Operator_Id START_DATE START_TIME)],
		REDUNDANT_DATA_COUNTERS                   => [],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(FILENAME)],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => -1,
		PRODUCE_PIF                               => 'True',
	},		
	
	{
		
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Joining PIF files after INFOINSERT to cater for missing INFO FILE.',
		INPUT_FILE_DESCRIPTION => [
			'^.*50331653(.*)-#-I-#-(.*)-#-FS\.pif$',
			'^.*50331653(.*)-#-I-#-(.*)-#-FS-#-S\.pif$',
		],
		OUTPUT_BLOCK_NAME                         => 'B50331653',
		OUTPUT_FILENAME_START                     => 'B50331653_JOIN',
		COUNTERS_TO_JOIN_ON                       => [qw(NodeB_Id Local_Cell_Id START_DATE START_TIME)],
		REDUNDANT_DATA_COUNTERS                   => [],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(FILENAME)],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => -1,
		PRODUCE_PIF                               => 'True',
	},			
	
	{
		
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Joining PIF files after INFOINSERT to cater for missing INFO FILE.',
		INPUT_FILE_DESCRIPTION => [
			'^.*50331654(.*)-#-I-#-(.*)-#-FS\.pif$',
			'^.*50331654(.*)-#-I-#-(.*)-#-FS-#-S\.pif$',
		],
		OUTPUT_BLOCK_NAME                         => 'B50331654',
		OUTPUT_FILENAME_START                     => 'B50331654_JOIN',
		COUNTERS_TO_JOIN_ON                       => [qw(NodeB_Id START_DATE START_TIME)],
		REDUNDANT_DATA_COUNTERS                   => [],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(FILENAME)],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => -1,
		PRODUCE_PIF                               => 'True',
	},	
	
	{
		
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Joining PIF files after INFOINSERT to cater for missing INFO FILE.',
		INPUT_FILE_DESCRIPTION => [
			'^.*50331655(.*)-#-I-#-(.*)-#-FS\.pif$',
			'^.*50331655(.*)-#-I-#-(.*)-#-FS-#-S\.pif$',
		],
		OUTPUT_BLOCK_NAME                         => 'B50331655',
		OUTPUT_FILENAME_START                     => 'B50331655_JOIN',
		COUNTERS_TO_JOIN_ON                       => [qw(NodeB_Id OBJECT_ID START_DATE START_TIME)],
		REDUNDANT_DATA_COUNTERS                   => [],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(FILENAME)],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => -1,
		PRODUCE_PIF                               => 'True',
	},		
	
	{
		
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Joining PIF files after INFOINSERT to cater for missing INFO FILE.',
		INPUT_FILE_DESCRIPTION => [
			'^.*50331656(.*)-#-I-#-(.*)-#-FS\.pif$',
			'^.*50331656(.*)-#-I-#-(.*)-#-FS-#-S\.pif$',
		],
		OUTPUT_BLOCK_NAME                         => 'B50331656',
		OUTPUT_FILENAME_START                     => 'B50331656_JOIN',
		COUNTERS_TO_JOIN_ON                       => [qw(NodeB_Id OBJECT_ID START_DATE START_TIME)],
		REDUNDANT_DATA_COUNTERS                   => [],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(FILENAME)],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => -1,
		PRODUCE_PIF                               => 'True',
	},			
	
	{
		
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Joining PIF files after INFOINSERT to cater for missing INFO FILE.',
		INPUT_FILE_DESCRIPTION => [
			'^.*50331657(.*)-#-I-#-(.*)-#-FS\.pif$',
			'^.*50331657(.*)-#-I-#-(.*)-#-FS-#-S\.pif$',
		],
		OUTPUT_BLOCK_NAME                         => 'B50331657',
		OUTPUT_FILENAME_START                     => 'B50331657_JOIN',
		COUNTERS_TO_JOIN_ON                       => [qw(NodeB_Id START_DATE START_TIME)],
		REDUNDANT_DATA_COUNTERS                   => [],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(FILENAME)],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => -1,
		PRODUCE_PIF                               => 'True',
	},	
	
	{
		
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Joining PIF files after INFOINSERT to cater for missing INFO FILE.',
		INPUT_FILE_DESCRIPTION => [
			'^.*50331658(.*)-#-I-#-(.*)-#-FS\.pif$',
			'^.*50331658(.*)-#-I-#-(.*)-#-FS-#-S\.pif$',
		],
		OUTPUT_BLOCK_NAME                         => 'B50331658',
		OUTPUT_FILENAME_START                     => 'B50331658_JOIN',
		COUNTERS_TO_JOIN_ON                       => [qw(NodeB_Id Local_Cell_Id START_DATE START_TIME)],
		REDUNDANT_DATA_COUNTERS                   => [],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(FILENAME)],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => -1,
		PRODUCE_PIF                               => 'True',
	},		
	
	{
		
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Joining PIF files after INFOINSERT to cater for missing INFO FILE.',
		INPUT_FILE_DESCRIPTION => [
			'^.*50331659(.*)-#-I-#-(.*)-#-FS\.pif$',
			'^.*50331659(.*)-#-I-#-(.*)-#-FS-#-S\.pif$',
		],
		OUTPUT_BLOCK_NAME                         => 'B50331659',
		OUTPUT_FILENAME_START                     => 'B50331659_JOIN',
		COUNTERS_TO_JOIN_ON                       => [qw(NodeB_Id OBJECT_ID START_DATE START_TIME)],
		REDUNDANT_DATA_COUNTERS                   => [],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(FILENAME)],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => -1,
		PRODUCE_PIF                               => 'True',
	},			
	
	{
		RULE_TYPE              => 'PERLIZE',
		RULE_DESCRIPTION       => 'Provide default RNC_ID if not inserted previously',
		INPUT_FILE_DESCRIPTION => [
			'^.*50331648_JOIN.*-#-.*-#-J\.pif$',
			'^.*50331649_JOIN.*-#-.*-#-J\.pif$',
			'^.*50331650_JOIN.*-#-.*-#-J\.pif$',
			'^.*50331651_JOIN.*-#-.*-#-J\.pif$',
			'^.*50331652_JOIN.*-#-.*-#-J\.pif$',
			'^.*50331653_JOIN.*-#-.*-#-J\.pif$',
			#### Added during v900r013
			'^.*50331654_JOIN.*-#-.*-#-J\.pif$',
			'^.*50331655_JOIN.*-#-.*-#-J\.pif$',
			'^.*50331656_JOIN.*-#-.*-#-J\.pif$',
			'^.*50331657_JOIN.*-#-.*-#-J\.pif$',
			'^.*50331658_JOIN.*-#-.*-#-J\.pif$',
			'^.*50331659_JOIN.*-#-.*-#-J\.pif$',
		],
		FILENAME_SUFFIX  => 'PZ',
		DATA_COUNTERS_OP => sub {
			my $d_ref = shift;

			if ( not exists $d_ref->{RNC_ID} or $d_ref->{RNC_ID} eq '' ) {
				$d_ref->{RNC_ID} = 'UNKNOWN';
			}
			
			return 0;
		},
		#PRODUCE_LIF => 'True',	

	},
	
	{
		RULE_TYPE              => 'PIF_REMOVE',
		RULE_DESC              => 'Remove INFOINSERT of RNC_ID input files and JOIN files',
		INPUT_FILE_DESCRIPTION => [
			'^.*50331648.*-#-I-#-.*-#-FS\.pif$',
			'^.*50331649.*-#-I-#-.*-#-FS\.pif$',
			'^.*50331650.*-#-I-#-.*-#-FS\.pif$',
			'^.*50331651.*-#-I-#-.*-#-FS\.pif$',
			'^.*50331652.*-#-I-#-.*-#-FS\.pif$',
			'^.*50331653.*-#-I-#-.*-#-FS\.pif$',
			'^.*50331654.*-#-I-#-.*-#-FS\.pif$',
			'^.*50331655.*-#-I-#-.*-#-FS\.pif$',
			'^.*50331656.*-#-I-#-.*-#-FS\.pif$',
			'^.*50331657.*-#-I-#-.*-#-FS\.pif$',
			'^.*50331658.*-#-I-#-.*-#-FS\.pif$',
			'^.*50331659.*-#-I-#-.*-#-FS\.pif$',
			'^II.*50331648.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^II.*50331649.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^II.*50331650.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^II.*50331651.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^II.*50331652.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^II.*50331653.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^II.*50331654.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^II.*50331655.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^II.*50331656.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^II.*50331657.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^II.*50331658.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^II.*50331659.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*50331648_JOIN.*-#-.*-#-J\.pif$',
			'^.*50331649_JOIN.*-#-.*-#-J\.pif$',
			'^.*50331650_JOIN.*-#-.*-#-J\.pif$',
			'^.*50331651_JOIN.*-#-.*-#-J\.pif$',
			'^.*50331652_JOIN.*-#-.*-#-J\.pif$',
			'^.*50331653_JOIN.*-#-.*-#-J\.pif$',
			'^.*50331654_JOIN.*-#-.*-#-J\.pif$',
			'^.*50331655_JOIN.*-#-.*-#-J\.pif$',
			'^.*50331656_JOIN.*-#-.*-#-J\.pif$',
			'^.*50331657_JOIN.*-#-.*-#-J\.pif$',
			'^.*50331658_JOIN.*-#-.*-#-J\.pif$',
			'^.*50331659_JOIN.*-#-.*-#-J\.pif$',			
		],
	},

	{
		RULE_TYPE              => 'ACCUMULATE',
		RULE_DESC              => 'Aggregrate B67109471 across Cells to NodeB level',
		INPUT_FILE_DESCRIPTION => ['^II-#-.*67109471.*-#-I-#-.*-#-FS-#-S-#-PZ\.pif$'],
		COUNTERS_TO_SORT_ON    => [qw(RNC_ID  NodeB_Id START_DATE START_TIME)],
		OUTPUT_BLOCK_NAME      => 'B67109471_GRP',
		PRODUCE_PIF            => 'True',
		NON_ADDITIVE_COUNTERS  => [qw( GP START_DATE Reliability START_TIME)],
		AVERAGE_COUNTERS       => [
			'C67203932',    #VS_HSUPA_MeanChThroughput
			'C67203850',    #VS_HSUPA_UE_Mean_Cell
		],
		AVERAGE_APPEND_STR    => "_AVG",
		AVERAGE_NO_APPEND_STR => [
			'C67203932',    #VS_HSUPA_MeanChThroughput
			'C67203850',    #VS_HSUPA_UE_Mean_Cell
		],
		REDUNDANT_DATA_COUNTERS => [
			qw(
			  CELL_ID
			  C67192367
			  C67192368
			  C67192371
			  C67192372
			  C67192373
			  C67192374
			  C67192470
			  C67192471
			  C67192472
			  C67192473
			  C67192474
			  C67192475
			  C67192476
			  C67192477
			  C67192480
			  C67192481
			  C67192482
			  C67192483
			  )
		],
	},
	
	{
		RULE_TYPE              => 'ACCUMULATE',
		RULE_DESC              => 'Aggregrate B67109471 across Cells to RNC level',
		INPUT_FILE_DESCRIPTION => ['^II-#-.*67109471.*-#-I-#-.*-#-FS-#-S-#-PZ\.pif$'],
		COUNTERS_TO_SORT_ON    => [qw(RNC_ID  START_DATE START_TIME)],
		OUTPUT_BLOCK_NAME      => 'B67109471_RNC_GRP',
		PRODUCE_PIF            => 'True',
		NON_ADDITIVE_COUNTERS  => [qw( GP START_DATE Reliability START_TIME)],
		AVERAGE_COUNTERS       => [
			'C67203932',    #VS_HSUPA_MeanChThroughput
			'C67203850',    #VS_HSUPA_UE_Mean_Cell
		],
		AVERAGE_APPEND_STR    => "_AVG",
		AVERAGE_NO_APPEND_STR => [
			'C67203932',    #VS_HSUPA_MeanChThroughput
			'C67203850',    #VS_HSUPA_UE_Mean_Cell
		],

		REDUNDANT_DATA_COUNTERS => [
			qw(
			  CELL_ID
			  NodeB_Id
			  C67192367
			  C67192368
			  C67192371
			  C67192372
			  C67192373
			  C67192374
			  C67192470
			  C67192471
			  C67192472
			  C67192473
			  C67192474
			  C67192475
			  C67192476
			  C67192477
			  C67192480
			  C67192481
			  C67192482
			  C67192483

			  )
		],
	},

	{
		RULE_TYPE              => 'ACCUMULATE',
		RULE_DESC              => 'Aggregrate B67109391 across Cells to NodeB level',
		INPUT_FILE_DESCRIPTION => ['^II-#-.*67109391.*-#-I-#-.*-#-FS-#-S-#-PZ\.pif$'],
		COUNTERS_TO_SORT_ON    => [qw(RNC_ID  NodeB_Id START_DATE START_TIME)],
		OUTPUT_BLOCK_NAME      => 'B67109391_GRP',
		PRODUCE_PIF            => 'True',
		NON_ADDITIVE_COUNTERS  => [qw( GP START_DATE Reliability START_TIME)],
		MAXIMUM_COUNTERS       => [
			'C67191167',    #VS_LC_DLCreditUsed_CELL_Max
			'C67191165',    #VS_LC_ULCreditUsed_CELL_Max
		],
		MAXIMUM_APPEND_STR    => "_MAX",
		MAXIMUM_NO_APPEND_STR => [
			'C67191167',    #VS_LC_DLCreditUsed_CELL_Max
			'C67191165',    #VS_LC_ULCreditUsed_CELL_Max
		],

		MINIMUM_COUNTERS => [
			'C67191168',    #VS_LC_DLCreditUsed_CELL_Min
			'C67191166',    #VS_LC_ULCreditUsed_CELL_Min
		],
		MINIMUM_APPEND_STR    => "_MIN",
		MINIMUM_NO_APPEND_STR => [
			'C67191168',    #VS_LC_DLCreditUsed_CELL_Min
			'C67191166',    #VS_LC_ULCreditUsed_CELL_Min
		],

		AVERAGE_COUNTERS => [
			'C67202570',    #VS_LC_DLCreditUsed_CELL
			'C67202567',    #VS_LC_ULCreditUsed_CELL
		],
		AVERAGE_APPEND_STR    => "_AVG",
		AVERAGE_NO_APPEND_STR => [
			'C67202570',    #VS_LC_DLCreditUsed_CELL
			'C67202567',    #VS_LC_ULCreditUsed_CELL
		],

		REDUNDANT_DATA_COUNTERS => [
			qw(
			  CELL_ID
			  C66666617
			  C66666618
			  C67180673
			  C67180674
			  C67180675
			  C67180676
			  C67180677
			  C67180678
			  C67181064
			  C67181065
			  C67181066
			  C67181071
			  C67181072
			  C67181073
			  C67181074
			  C67181075
			  C67181076
			  C67181077
			  C67181078
			  C67181079
			  C67181080
			  C67189844
			  C67189845
			  C67189852
			  C67189853
			  C67189856
			  C67189857
			  C67189858
			  C67189859
			  C67189860
			  C67189861
			  C67190433
			  C67190434
			  C67190435
			  C67190436
			  C67190437
			  C67190438
			  C67190439
			  C67190440
			  C67190441
			  C67190442
			  C67190443
			  C67190444
			  C67190519
			  C67190520
			  C67190706
			  C67190707
			  C67190846
			  C67190847
			  C67199663
			  C67199664
			  C67199736
			  C67199792
			  C67202917
			  C67202918
			  C67202919
			  C67202920
			  C67202921
			  C67203400
			  C67203401
			  C67203402
			  C67203403
			  )
		],
	},
	{
		RULE_TYPE              => 'ACCUMULATE',
		RULE_DESC              => 'Aggregrate 67109390 across Cells to NodeB level',
		INPUT_FILE_DESCRIPTION => ['^II-#-.*67109390.*-#-I-#-.*-#-FS-#-S-#-PZ\.pif$'],
		COUNTERS_TO_SORT_ON    => [qw(RNC_ID NodeB_Id START_DATE START_TIME)],
		OUTPUT_BLOCK_NAME      => 'B67109390_GRP',
		PRODUCE_PIF            => 'True',
		NON_ADDITIVE_COUNTERS  => [qw(GP START_DATE Reliability START_TIME)],

		AVERAGE_COUNTERS => [
			'C67202894',    #vs_hsdpa_meanchthroughput
			'C67190567',    #vs_hsdpa_meanchthroughput_times
			'C67189840',    #vs_hsdpa_meanchthroughput_totalbytes
		],
		AVERAGE_APPEND_STR    => "_AVG",
		AVERAGE_NO_APPEND_STR => [
			'C67202894',    #vs_hsdpa_meanchthroughput
			'C67190567',    #vs_hsdpa_meanchthroughput_times
			'C67189840',    #vs_hsdpa_meanchthroughput_totalbytes
		],

		REDUNDANT_DATA_COUNTERS => [
		#FixPack1 replace CELL_ID with Cell_Id
			qw(
			  Cell_Id
			  C66666673
			  C66666674
			  C66666675
			  C67189830
			  C67189831
			  C67189832
			  C67189833
			  C67190690
			  C67190691
			  C67190692
			  C67190693
			  C67190694
			  C67190695
			  C67190696
			  C67190697
			  C67190698
			  C67190699
			  C67190700
			  C67190701
			  C67190702
			  C67190703
			  C67191157
			  C67191158
			  C67191159
			  C67191160
			  )
		],
	},
	{
		RULE_TYPE              => 'ACCUMULATE',
		RULE_DESC              => 'Aggregrate 67109390 across Cells to RNC level',
		INPUT_FILE_DESCRIPTION => ['^II-#-.*67109390.*-#-I-#-.*-#-FS-#-S-#-PZ\.pif$'],
		COUNTERS_TO_SORT_ON    => [qw(RNC_ID START_DATE START_TIME)],
		OUTPUT_BLOCK_NAME      => 'B67109390_RNC_GRP',
		PRODUCE_PIF            => 'True',
		NON_ADDITIVE_COUNTERS  => [qw( GP START_DATE Reliability START_TIME)],

		AVERAGE_COUNTERS => [
			'C67202894',    #vs_hsdpa_meanchthroughput
			'C67190567',    #vs_hsdpa_meanchthroughput_times
			'C67189840',    #vs_hsdpa_meanchthroughput_totalbytes
		],
		AVERAGE_APPEND_STR    => "_AVG",
		AVERAGE_NO_APPEND_STR => [
			'C67202894',    #vs_hsdpa_meanchthroughput
			'C67190567',    #vs_hsdpa_meanchthroughput_times
			'C67189840',    #vs_hsdpa_meanchthroughput_totalbytes
		],

		REDUNDANT_DATA_COUNTERS => [
			qw(
			  CELL_ID
			  NodeB_Id
			  C66666673
			  C66666674
			  C66666675
			  C67189830
			  C67189831
			  C67189832
			  C67189833
			  C67190690
			  C67190691
			  C67190692
			  C67190693
			  C67190694
			  C67190695
			  C67190696
			  C67190697
			  C67190698
			  C67190699
			  C67190700
			  C67190701
			  C67190702
			  C67190703
			  C67191157
			  C67191158
			  C67191159
			  C67191160
			  )
		],
	},
	
	{
		RULE_TYPE              => 'ACCUMULATE',
		RULE_DESC              => 'Aggregrate 67109387 across Cells to NodeB level',
		INPUT_FILE_DESCRIPTION => ['^.*67109387.*-#-I-#-.*-#-FS-#-S-#-PZ\.pif$'],
		COUNTERS_TO_SORT_ON    => [qw(RNC_ID NodeB_Id START_DATE START_TIME)],
		OUTPUT_BLOCK_NAME      => 'B67109387_GRP',
		PRODUCE_PIF            => 'True',
		NON_ADDITIVE_COUNTERS  => [qw(GP START_DATE Reliability START_TIME)],

		AVERAGE_COUNTERS => [
			'C67202820',    #VS_PS_Bkg_Kbps_DL16
			'C67202821',    #VS_PS_Bkg_Kbps_DL32
		],
		AVERAGE_APPEND_STR    => "_AVG",
		AVERAGE_NO_APPEND_STR => [
			'C67202820',    #VS_PS_Bkg_Kbps_DL16
			'C67202821',    #VS_PS_Bkg_Kbps_DL32
		],
		REDUNDANT_DATA_COUNTERS => [
		#FixPack1 replace CELL_ID with Cell_Id
			qw(
			  Cell_Id
			  C67189830
			  C67189831
			  C67189832
			  C67189833
			  C67190690
			  C67190691
			  C67190692
			  C67190693
			  C67190694
			  C67190695
			  C67190696
			  C67190697
			  C67190698
			  C67190699
			  C67190700
			  C67190701
			  C67190702
			  C67190703
			  C67191157
			  C67191158
			  C67191159
			  C67191160
			  )
		],
	},

	#------------------------------------------------------------------------------------
	# Infoinsert Network and Region ID for Acuumulation PIF
	#-------------------------------------------------------------------------------------
	{
		RULE_TYPE              => 'INFOINSERT',
		RULE_DESC              => 'Insert Network and Region Id',
		INPUT_FILE_DESCRIPTION => [
			'II-#-.*-#-I-#-.*-#-FS-#-S-#-PZ-#-B67109471_GRP-#-A.pif', 
			'II-#-.*-#-I-#-.*-#-FS-#-S-#-PZ-#-B67109471_RNC_GRP-#-A.pif',
			'II-#-.*-#-I-#-.*-#-FS-#-S-#-PZ-#-B67109391_GRP-#-A.pif',
		    'II-#-.*-#-I-#-.*-#-FS-#-S-#-PZ-#-B67109390_GRP-#-A.pif',
			'II-#-.*-#-I-#-.*-#-FS-#-S-#-PZ-#-B67109390_RNC_GRP-#-A.pif',
		],
		NAMES_USED_TO_ID_DATA_RECORD        => [qw(RNC_ID)],
		INFO_FILE_DESCRIPTION               => 'Huawei_UTRAN_Network_Region.csv-#-I\.pif$',
		NAMES_USED_TO_ID_INFORMATION        => [qw(RNC_ID)],
		ONLY_INSERT                         => [ 'Network_ID', 'Region_ID' ],
		REDUNDAT_DATA_COUNTERS              => [''],
		DEFAULT_NULL_VALUE                  => '',
		HEADER_NAMES_USED_TO_ID_INFORMATION => [''],
		HEADER_NAMES_USED_TO_ID_DATA_RECORD => [''],
		WRITE_DATA_LINE                     => 'True',
		PRODUCE_PIF                         => 'True',
		#OUTPUT_FORMAT                       => 'LIF_Writer',
	},

        {
                RULE_TYPE              => 'PERLIZE',
                RULE_DESCRIPTION       => 'Provide default Network_ID and Region_ID if not inserted previously',
                INPUT_FILE_DESCRIPTION => [
                        'II-#-.*-#-I-#-.*-#-FS-#-S-#-PZ-#-B67109471_GRP-#-A-#-S.pif',
                        'II-#-.*-#-I-#-.*-#-FS-#-S-#-PZ-#-B67109471_RNC_GRP-#-A-#-S.pif',
                        'II-#-.*-#-I-#-.*-#-FS-#-S-#-PZ-#-B67109391_GRP-#-A-#-S.pif',
                        'II-#-.*-#-I-#-.*-#-FS-#-S-#-PZ-#-B67109390_GRP-#-A-#-S.pif',
                        'II-#-.*-#-I-#-.*-#-FS-#-S-#-PZ-#-B67109390_RNC_GRP-#-A-#-S.pif',
                ],
                FILENAME_SUFFIX  => 'PZ',
                DATA_COUNTERS_OP => sub {
                        my $d_ref = shift;

                        if ( not exists $d_ref->{Network_ID} or $d_ref->{Network_ID} eq '' ) {
                                $d_ref->{Network_ID} = 'UNDEFINED';
                        }

                        if ( not exists $d_ref->{Region_ID} or $d_ref->{Region_ID} eq '' ) {
                                $d_ref->{Region_ID} = 'UNDEFINED';
                        }

                        return 0;
                },
                PRODUCE_LIF => 'True',
        },

	#join 67109387 & 67109390 to get nodeb traffic busy hour. output 67109387
	# Inject B67109390_GRP.C67189840 (VS_HSDPA_MeanChThroughput_TotalBytes) into B67109387_GRP
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Joining for Cell_Traffic_busy_hour at NodeB level',
		INPUT_FILE_DESCRIPTION                    => [
			'^II-#-.*67109390(.*)-#-B67109390_GRP-#-A\.pif$',
			'^II-#-.*67109387(.*)-#-B67109387_GRP-#-A\.pif$', ],
		OUTPUT_BLOCK_NAME                         => 'B67109387_GRP',
		OUTPUT_FILENAME_START                     => 'B67109387_GRP',
		COUNTERS_TO_JOIN_ON                       => [qw(RNC_ID NodeB_Id CELL_ID START_DATE START_TIME)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(FILENAME)],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => 1,
		REDUNDANT_DATA_COUNTERS                   => [
			qw(
			  C66666673
			  C66666674
			  C66666675
			  C67189782
			  C67189783
			  C67189784
			  C67189785
			  C67189786
			  C67189830
			  C67189831
			  C67189832
			  C67189833
			  C67189834
			  C67189835
			  C67189836
			  C67189837
			  C67190391
			  C67190392
			  C67190403
			  C67190567
			  C67190688
			  C67190689
			  C67190690
			  C67190691
			  C67190692
			  C67190693
			  C67190694
			  C67190695
			  C67190696
			  C67190697
			  C67190698
			  C67190699
			  C67190700
			  C67190701
			  C67190702
			  C67190703
			  C67190704
			  C67190705
			  C67191157
			  C67191158
			  C67191159
			  C67191160
			  C67191161
			  C67191162
			  C67191163
			  C67191164
			  C67199637
			  C67199638
			  C67199639
			  C67199640
			  C67199641
			  C67199739
			  C67199740
			  C67199741
			  C67202422
			  C67202423
			  C67202807
			  C67202808
			  C67202894
			  C67202932
			  C67202941
			  )
		],
		PRODUCE_PIF => 'True',
	},

	#only need to do PIF_REMOVE
	{
		RULE_TYPE              => 'PIF_REMOVE',
		RULE_DESC              => 'Remove ACCUMULATEd and JOINed input files',
		INPUT_FILE_DESCRIPTION => [
			'^II-#-.*67109390(.*)-#-B67109390_GRP-#-A\.pif$',
			'^II-#-.*67109387(.*)-#-B67109387_GRP-#-A\.pif$',
		],
	},

	{

		#67109429 is no directly used by TP; so inject into 67109428
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Joining for 67109428 and 67109429',
		INPUT_FILE_DESCRIPTION                    => [ '^.*67109429(.*-#-I-#-.*-#-FS)\.pif$', 
																					  '^.*67109428(.*-#-I-#-.*-#-FS)\.pif$' ],
		OUTPUT_BLOCK_NAME                         => 'B67109428',
		OUTPUT_FILENAME_START                     => 'B67109428',
		COUNTERS_TO_JOIN_ON                       => [qw(RNC_ID OBJECT_ID START_DATE START_TIME)],
		REDUNDANT_DATA_COUNTERS                   => [],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(FILENAME)],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => 1,
		PRODUCE_PIF                               => 'True',

		#OUTPUT_FORMAT		=> 'LIF_Writer',
	},

	{
		#Inject B67109378.C67199620 , B67109378.C67199556 into B67109508
		RULE_TYPE               => 'JOIN',
		RULE_DESC               => 'Joining for Cell_ASE_busy_hour',
		INPUT_FILE_DESCRIPTION  => [
			'^II-#-.*67109508(.*-#-I-#-.*-#-FS)-#-S-#-PZ\.pif$',
			'^II-#-.*67109378(.*-#-I-#-.*-#-FS)-#-S-#-PZ\.pif$'
		],
		OUTPUT_BLOCK_NAME       => 'B67109508',
		OUTPUT_FILENAME_START   => 'B67109508',
		COUNTERS_TO_JOIN_ON     => [qw(RNC_ID NodeB_Id CELL_ID  START_DATE START_TIME)],
		REDUNDANT_DATA_COUNTERS => [
			qw(
			  C67180113
			  C67180114
			  C67180115
			  C67180116
			  C67180119
			  C67180120
			  C67180121
			  C67180122
			  C67180123
			  C67180124
			  C67180125
			  C67180128
			  C67180129
			  C67180130
			  C67180140
			  C67180141
			  C67180142
			  C67180143
			  C67180146
			  C67180147
			  C67180148
			  C67190599
			  C67190600
			  C67190684
			  C67190685
			  C67190686
			  C67190687
			  C67199557
			  C67199558
			  C67199559
			  C67199560
			  C67199561
			  C67199562
			  C67199563
			  C67199564
			  C67199565
			  C67199566
			  C67199567
			  C67199568
			  C67199569
			  C67199570
			  C67199571
			  C67199572
			  C67199573
			  C67199574
			  C67199575
			  C67199576
			  C67199577
			  C67199578
			  C67199579
			  C67199580
			  C67199581
			  C67199582
			  C67199583
			  C67199584
			  C67199585
			  C67199586
			  C67199587
			  C67199588
			  C67199589
			  C67199590
			  C67199591
			  C67199592
			  C67199593
			  C67199594
			  C67199595
			  C67199596
			  C67199597
			  C67199598
			  C67199599
			  C67199600
			  C67199601
			  C67199602
			  C67199603
			  C67199604
			  C67199605
			  C67199619
			  C67199621
			  C67199622
			  C67199623
			  C67199624
			  C67199625
			  C67199626
			  C67199627
			  C67199628
			  C67199629
			  C67199630
			  C67199631
			  C67199632
			  C67199780
			  C67199781
			  C67199781
			  )
		],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(FILENAME)],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => 1,
		PRODUCE_PIF                               => 'True',

		#OUTPUT_FORMAT		=> 'LIF_Writer',
	},
	{

		# Inject B67109390.C67189840 (VS_HSDPA_MeanChThroughput_TotalBytes) into B67109387
		RULE_TYPE               => 'JOIN',
		RULE_DESC               => 'Joining for Cell_Traffic_busy_hour',
		INPUT_FILE_DESCRIPTION  => [
			'^II-#-.*67109390(.*-#-I-#-.*-#-FS)-#-S-#-PZ\.pif$',
			'^II-#-.*67109387(.*-#-I-#-.*-#-FS)-#-S-#-PZ\.pif$'
		],
		OUTPUT_BLOCK_NAME       => 'B67109387',
		OUTPUT_FILENAME_START   => 'B67109387',
		COUNTERS_TO_JOIN_ON     => [qw(RNC_ID NodeB_Id CELL_ID START_DATE START_TIME)],
		REDUNDANT_DATA_COUNTERS => [
			qw(
			  C66666673
			  C66666674
			  C66666675
			  C67189830
			  C67189831
			  C67189832
			  C67189833
			  C67189834
			  C67189835
			  C67189836
			  C67189837
			  C67190567
			  C67190688
			  C67190689
			  C67190690
			  C67190691
			  C67190692
			  C67190693
			  C67190694
			  C67190695
			  C67190696
			  C67190697
			  C67190698
			  C67190699
			  C67190700
			  C67190701
			  C67190702
			  C67190703
			  C67190704
			  C67190705
			  C67191157
			  C67191158
			  C67191159
			  C67191160
			  C67191161
			  C67191162
			  C67191163
			  C67191164
			  C67202894
			  C67202932
			  C67202941
			  )
		],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(FILENAME)],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => 1,
		PRODUCE_PIF                               => 'True',
	},

	#------------------------------------------------------------------------------------
	# Infoinsert Network and Region ID for JOIN PIF
	#-------------------------------------------------------------------------------------
	# B2 - CR 92941 - to support XML file
	{
		RULE_TYPE                    => 'INFOINSERT',
		RULE_DESC                    => 'Insert Network and Region Id',
		INPUT_FILE_DESCRIPTION       => [
			'B67109387_GRP-#-.*-#-J.pif',
			#'B67109428-#-.*-#-J.pif',
			'B67109428-#-.*-#-J.pif',
			'B67109508-#-.*-#-J.pif',
			'B67109387-#-.*-#-J.pif',
		],
		NAMES_USED_TO_ID_DATA_RECORD => [qw(RNC_ID)],
		INFO_FILE_DESCRIPTION        => 'Huawei_UTRAN_Network_Region.csv-#-I\.pif$',
		NAMES_USED_TO_ID_INFORMATION => [qw(RNC_ID)],
		ONLY_INSERT                         => [ 'Network_ID', 'Region_ID' ],
		REDUNDAT_DATA_COUNTERS              => [''],
		HEADER_NAMES_USED_TO_ID_INFORMATION => [''],
		HEADER_NAMES_USED_TO_ID_DATA_RECORD => [''],
		DEFAULT_NULL_VALUE                  => '',
		WRITE_DATA_LINE                     => 'True',
		PRODUCE_PIF			    => 'True',
		#OUTPUT_FORMAT                       => 'LIF_Writer',
	},

		        {
                RULE_TYPE              => 'PERLIZE',
                RULE_DESCRIPTION       => 'Provide default Network_ID and Region_ID if not inserted previously',
                INPUT_FILE_DESCRIPTION => [
                        'B67109387_GRP-#-.*-#-J-#-S.pif',
                        #'B67109428-#-.*-#-J.pif',
                        'B67109428-#-.*-#-J-#-S.pif',
                        'B67109508-#-.*-#-J-#-S.pif',
                        'B67109387-#-.*-#-J-#-S.pif',

                ],
                FILENAME_SUFFIX  => 'PZ',
                DATA_COUNTERS_OP => sub {
                        my $d_ref = shift;

                        if ( not exists $d_ref->{Network_ID} or $d_ref->{Network_ID} eq '' ) {
                                $d_ref->{Network_ID} = 'UNDEFINED';
                        }

                        if ( not exists $d_ref->{Region_ID} or $d_ref->{Region_ID} eq '' ) {
                                $d_ref->{Region_ID} = 'UNDEFINED';
                        }

                        return 0;
                },
                PRODUCE_LIF => 'True',
        },

	#need PIF REMOVE here
	{
		RULE_TYPE              => 'PIF_REMOVE',
		RULE_DESC              => 'Remove JOIN input files',
		INPUT_FILE_DESCRIPTION => [
			'^II-#-.*67109387(.*-#-I-#-.*-#-FS)-#-S\.pif$',    #comment for alm00198998
			'^II-#-.*67109508(.*-#-I-#-.*-#-FS)-#-S\.pif$',    #comment for alm00198998
			#'^.*67109428(.*-#-I-#-.*-#-FS)\.pif$',    #comment for alm00198998
			'^.*67109428(.*-#-I-#-.*-#-FS)\.pif$',
			'^67109387-#-.*-#-J\.pif$',
			'^67109387_GRP-#-.*-#-J\.pif$',
		],
	},

	# To split the counter PROC1_ID into 3 blocks, B67109453, B67109453_V200 and B67109453_V900
	{
		RULE_TYPE                   => 'FILE_SPLIT',
		RULE_DESC                   => 'Split into different block based on counter PROC1_ID',
		INPUT_FILE_DESCRIPTION      => ['^.*67109453.*-#-I-#-.*-#-FS\.pif'],
		COUNTERS_USED_TO_SPLIT_FILE => { PROC1_ID => '(.*)', },
		SPLIT_COUNTERS_ORDER        => [qw(PROC1_ID)],
		PRODUCE_PIF                 => 'True',
		PRODUCE_LIF                 => 0,
	},

        {   #v900r011
                RULE_TYPE              => 'PIF_2_OUTPUT',
                RULE_DESC              => 'Change blockname into B67109453_V900',
                INPUT_FILE_DESCRIPTION => ['^.*67109453.*-#-I-#-.*-#-FS-#-CPUS-#-FS\.pif'],
                DEFAULT_NULL_VALUE     => '',
                OUTPUT_BLOCK_NAME      => 'B67109453_V900',
                PRODUCE_PIF            => 'True',
                #OUTPUT_FORMAT          => 'LIF_Writer',
        },

        {
                RULE_TYPE              => 'PIF_2_OUTPUT',
                RULE_DESC              => 'Change blockname into B67109453_V200',
                INPUT_FILE_DESCRIPTION => ['^.*67109453.*-#-I-#-.*-#-FS-#-SPU-#-FS\.pif'],
                DEFAULT_NULL_VALUE     => '',
                OUTPUT_BLOCK_NAME      => 'B67109453_V200',
                PRODUCE_PIF            => 'True',
                #OUTPUT_FORMAT          => 'LIF_Writer',
        },

        {
                RULE_TYPE => 'PIF_2_OUTPUT',
                RULE_DESC => 'Output remaining block 67109453',

                #INPUT_FILE_DESCRIPTION  => ['^.*67109453.*-#-I-#-.*-#-FS-#-Frame-#-FS\.pif'],
                INPUT_FILE_DESCRIPTION => ['^.*67109453.*-#-I-#-.*-#-FS-#-Frame-#-FS\.pif'],
                DEFAULT_NULL_VALUE     => '',
                PRODUCE_PIF            => 'True',
                #OUTPUT_FORMAT          => 'LIF_Writer',
        },

        {  #v900r011
                RULE_TYPE => 'PIF_2_OUTPUT',
                RULE_DESC => 'Change blockname into B67109549_V900',

                #INPUT_FILE_DESCRIPTION  => ['^.*67109549.*-#-I-#-FIBER-#-FS-#-S\.pif'],
                INPUT_FILE_DESCRIPTION => ['^.*67109549.*-#-I-#-\d{2}:\d{2}-#-FS-#-FIBER-#-FS\.pif'],  #r11, corrected during v900r011
                DEFAULT_NULL_VALUE     => '',
                OUTPUT_BLOCK_NAME      => 'B67109549_V900',
                PRODUCE_PIF            => 'True',
                OUTPUT_FORMAT          => 0,
        },

        {
                RULE_TYPE => 'PIF_2_OUTPUT',
                RULE_DESC => 'Change blockname into B67109549_V200',

                #INPUT_FILE_DESCRIPTION  => ['^.*67109549.*-#-I-#-UOI-#-FS-#-S\.pif'],
                INPUT_FILE_DESCRIPTION => ['^.*67109549.*-#-I-#-\d{2}:\d{2}-#-FS-#-UOI-#-FS\.pif'],  #r11, corrected during v900r011
                DEFAULT_NULL_VALUE     => '',
                OUTPUT_BLOCK_NAME      => 'B67109549_V200',
                PRODUCE_PIF            => 'True',
                OUTPUT_FORMAT          => 0,
        },

        {
                RULE_TYPE => 'PIF_2_OUTPUT',
                RULE_DESC => 'Change blockname into B67109549',

                #INPUT_FILE_DESCRIPTION  => ['^.*67109549.*-#-I-#-CELL-#-FS-#-S\.pif'],
                INPUT_FILE_DESCRIPTION => ['^.*67109549.*-#-I-#-\d{2}:\d{2}-#-FS-#-CELL-#-FS-#-S-#-S\.pif'],    #r11, corrected during v900r011
                DEFAULT_NULL_VALUE     => '',
                OUTPUT_BLOCK_NAME      => 'B67109549',
                PRODUCE_PIF            => 'True',
                OUTPUT_FORMAT          => 0,
        },

       {
               RULE_TYPE              => 'PIF_REMOVE',
               RULE_DESC              => 'Remove for B67109549',
               INPUT_FILE_DESCRIPTION => [
                       '^II-#-.*67109549.*-#-I-#-\d{2}:\d{2}-#-FS-#-CELL-#-FS-#-S\.pif',    #r11, added during v900r011
               '^.*67109549.*-#-I-#-\d{2}:\d{2}-#-FS-#-UOI-#-FS\.pif',              #r11, added during v900r011
                       '^.*67109549.*-#-I-#-\d{2}:\d{2}-#-FS-#-FIBER-#-FS\.pif',            #r11, added during v900r011
               ],
       },

	#------------------------------------------------------------------------------------
	# Infoinsert Network and Region ID for  File Split
	#-------------------------------------------------------------------------------------
	{
		RULE_TYPE              => 'INFOINSERT',
		RULE_DESC              => 'Insert Network and Region Id',
		INPUT_FILE_DESCRIPTION => [
			'^.*67109453.*-#-I-#-.*-#-FS-#-CPUS-#-FS-#-P\.pif',    #v900r011
			'^.*67109453.*-#-I-#-.*-#-FS-#-SPU-#-FS-#-P\.pif',
			'^.*67109453.*-#-I-#-.*-#-FS-#-Frame-#-FS-#-P\.pif',

			# '^II-#-.*67109549.*-#-I-#-CELL-#-FS-#-S\.pif',
			# '^.*67109549.*-#-I-#-UOI-#-FS\.pif',
			# '^.*67109549.*-#-I-#-FIBER-#-FS\.pif'],
			'^II-#-.*67109549.*-#-I-#-\d{2}:\d{2}-#-FS-#-CELL-#-FS-#-S-#-P\.pif',    #r11, corrected during v900r011
			'^.*67109549.*-#-I-#-\d{2}:\d{2}-#-FS-#-UOI-#-FS-#-P\.pif',              #r11, corrected during v900r011
			'^.*67109549.*-#-I-#-\d{2}:\d{2}-#-FS-#-FIBER-#-FS-#-P\.pif'
		],                                                                       #r11, corrected during v900r011
		NAMES_USED_TO_ID_DATA_RECORD        => [qw(RNC_ID)],
		INFO_FILE_DESCRIPTION               => 'Huawei_UTRAN_Network_Region.csv-#-I\.pif$',
		NAMES_USED_TO_ID_INFORMATION        => [qw(RNC_ID)],
		ONLY_INSERT                         => [ 'Network_ID', 'Region_ID' ],
		REDUNDAT_DATA_COUNTERS              => [''],
		HEADER_NAMES_USED_TO_ID_INFORMATION => [''],
		HEADER_NAMES_USED_TO_ID_DATA_RECORD => [''],
		DEFAULT_NULL_VALUE                  => '',
		WRITE_DATA_LINE                     => 'True',
		PRODUCE_PIF                         => 'True',
	},

	 {
                RULE_TYPE              => 'PERLIZE',
                RULE_DESCRIPTION       => 'Provide default Network_ID and Region_ID if not inserted previously',
                INPUT_FILE_DESCRIPTION => [
                        '^.*67109453.*-#-I-#-.*-#-FS-#-CPUS-#-FS-#-P-#-S\.pif',    #v900r011
                        '^.*67109453.*-#-I-#-.*-#-FS-#-SPU-#-FS-#-P-#-S\.pif',
                        '^.*67109453.*-#-I-#-.*-#-FS-#-Frame-#-FS-#-P-#-S\.pif',
                        '^II-#-.*67109549.*-#-I-#-\d{2}:\d{2}-#-FS-#-CELL-#-FS-#-S-#-P-#-S\.pif',    #r11, corrected during v900r011
                        '^.*67109549.*-#-I-#-\d{2}:\d{2}-#-FS-#-UOI-#-FS-#-P-#-S\.pif',              #r11, corrected during v900r011
                        '^.*67109549.*-#-I-#-\d{2}:\d{2}-#-FS-#-FIBER-#-FS-#-P-#-S\.pif'
                ],
                FILENAME_SUFFIX  => 'PZ',
                DATA_COUNTERS_OP => sub {
                        my $d_ref = shift;

                        if ( not exists $d_ref->{Network_ID} or $d_ref->{Network_ID} eq '' ) {
                                $d_ref->{Network_ID} = 'UNDEFINED';
                        }

                        if ( not exists $d_ref->{Region_ID} or $d_ref->{Region_ID} eq '' ) {
                                $d_ref->{Region_ID} = 'UNDEFINED';
                        }

                        return 0;
                },
                PRODUCE_LIF => 'True',
        },

       {
               RULE_TYPE              => 'PIF_REMOVE',
               RULE_DESC              => 'Remove for B67109453 & remain duplicate input files',
               INPUT_FILE_DESCRIPTION => [
                       '^.*67109453.*-#-I-#-.*-#-FS\.pif',
                       '^.*67109453.*-#-I-#-.*-#-FS-#-S\.pif',
               ],
       },

	#------------------------------------------------------------------------------------
	# Infoinsert Network and Region ID for  others remain file
	#-------------------------------------------------------------------------------------
	{
		RULE_TYPE              => 'INFOINSERT',
		RULE_DESC              => 'Insert Network and Region Id',
		INPUT_FILE_DESCRIPTION => [
			'^II-#-.*-#-I-#-.*-#-FS-#-S\.pif$',
			#'II-#-.*PZ\.pif$',
			#'II-#-.*(50331648|50331649|50331650|50331651|50331652|50331653|50331654|50331655|50331656|50331657|50331658|50331659).*PZ\.pif$',
			'^.*(50331648|50331649|50331650|50331651|50331652|50331653|50331654|50331655|50331656|50331657|50331658|50331659).*PZ\.pif$',
			'^.*-#-FS\.pif$',
			'^.*-#-FS-#-S-#-PZ\.pif$',
			'^.*82833917.*-#-I-#-\d{2}:\d{2}-#-FS\.pif$',    #v900r011
			'^.*82833961.*-#-I-#-\d{2}:\d{2}-#-FS\.pif$',    #v900r011
		],
		NAMES_USED_TO_ID_DATA_RECORD        => [qw(RNC_ID)],
		INFO_FILE_DESCRIPTION               => 'Huawei_UTRAN_Network_Region.csv-#-I\.pif$',
		NAMES_USED_TO_ID_INFORMATION        => [qw(RNC_ID)],
		ONLY_INSERT                         => [ 'Network_ID', 'Region_ID' ],
		DEFAULT_NULL_VALUE                  => '',
		REDUNDAT_DATA_COUNTERS              => [''],
		HEADER_NAMES_USED_TO_ID_INFORMATION => [''],
		HEADER_NAMES_USED_TO_ID_DATA_RECORD => [''],
		WRITE_DATA_LINE                     => 'True',
		PRODUCE_PIF                         => 'True',
	},

        {
                RULE_TYPE              => 'PIF_REMOVE',
                RULE_DESC              => 'Remove remaining data files',
                INPUT_FILE_DESCRIPTION => [
			'^.*(82834952|82863914|82863927|82863928|82863947|82863949|82863953|67109365|67109366|67109367|67109369|67109372|67109373|67109378|67109379|67109380|67109381|67109385|67109390|67109391|67109471|67109508|67109509|67109523|67109393|67109368|67109474|67109370|67109371|67109374|67109375|67109376|67109377|67109382|67109383|67109384|67109386|67109388|67109389|67109392|67109413|67109505|67109510).*-#-FS-#-S\.pif$',
			#'^.*(82834952|82863914|82863927|82863928|82863947|82863949|82863953|67109365|67109366|67109367|67109369|67109372|67109373|67109378|67109379|67109380|67109381|67109385|67109390|67109391|67109471|67109508|67109509|67109523|67109393|67109368|67109474|67109370|67109371|67109374|67109375|67109376|67109377|67109382|67109383|67109384|67109386|67109388|67109389|67109392|67109413|67109505|67109510).*-#-FS-#-S-#-PZ\.pif$', 
			'^.*(50331648|50331649|50331650|50331651|50331652|50331653|50331654|50331655|50331656|50331657|50331658|50331659).*PZ\.pif$',
			'^II-#-.*67109508-#-.*PZ-#-S\.pif$',
			'^II-#-.*67109387-#-.*PZ-#-S\.pif$'],
			
	},

        {
                RULE_TYPE              => 'PERLIZE',
                RULE_DESCRIPTION       => 'Provide default Network_ID and Region_ID if not inserted previously',
                INPUT_FILE_DESCRIPTION => [
                        '^II-#-.*-#-I-#-.*-#-FS-#-S-#-S\.pif$',
                        'II-#-.*PZ-#-S\.pif$',
                        '^.*-#-.*PZ-#-S\.pif$',
                        '^.*-#-FS-#-S\.pif$',
                        '^.*82833917.*-#-I-#-\d{2}:\d{2}-#-FS-#-S\.pif$',    #v900r011
                        '^.*82833961.*-#-I-#-\d{2}:\d{2}-#-FS-#-S\.pif$',    #v900r011
			'^.*(pmresult_|B)(?!67109378|67109390|67109428).*-#-FS-#-S.pif$',     #add for alm00198998 only block 67109429 is excluded
                ],
                FILENAME_SUFFIX  => 'PZ',
                DATA_COUNTERS_OP => sub {
                        my $d_ref = shift;

                        if ( not exists $d_ref->{Network_ID} or $d_ref->{Network_ID} eq '' ) {
                                $d_ref->{Network_ID} = 'UNDEFINED';
                        }

                        if ( not exists $d_ref->{Region_ID} or $d_ref->{Region_ID} eq '' ) {
                                $d_ref->{Region_ID} = 'UNDEFINED';
                        }

                        return 0;
                },
                PRODUCE_PIF => 'True',
                PRODUCE_LIF => 'True',
	},

	
	
	{
		RULE_TYPE              => 'PIF_REMOVE',
		RULE_DESC              => 'Remove remaining data files',
		INPUT_FILE_DESCRIPTION => [
			#'^II-#-.*-#-I-#-.*-#-FS-#-S\.pif$',    #comment for alm00198998
			'^II-#-.*(pmresult_|B)(?!67109378|67109387|67109390|67109508).*-#-FS-#-S.pif$',    #add for alm00198998
			'^II-#-.*(pmresult_|B)(?!82834952|82863914|82863927|82863928|82863947|82863949|82863953).*-#-FS-#-S.pif$',   
			#'II-#-.*PZ\.pif$',
			#'^.*-#-FS\.pif$',    #comment for alm00198998
			'^.*(pmresult_|B)(?!67109428|67109429|82834001|82834002|82834003|82863915|82863925|82863929|82833952).*-#-FS\.pif$',    #add for alm00198998
			'^.*82833917.*-#-I-#-\d{2}:\d{2}-#-FS\.pif$',    #v900r011
			'^.*82833961.*-#-I-#-\d{2}:\d{2}-#-FS\.pif$',    #v900r011
		],
	},

	#--------------------------------------------
	# VN
	#-------------------------------------------
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Joining for Cell_Traffic_busy_hour at NodeB level',
		INPUT_FILE_DESCRIPTION                    => [
			'^II-#-.*67109390(.*)-#-B67109390_GRP-#-A\.pif$',
			'^II-#-.*67109387(.*)-#-B67109387_GRP-#-A\.pif$',
		],
		OUTPUT_BLOCK_NAME                         => 'B67109387_GRP',
		OUTPUT_FILENAME_START                     => 'B67109387_GRP',
		COUNTERS_TO_JOIN_ON                       => [qw(RNC_ID NodeB_Id CELL_ID START_DATE START_TIME)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(FILENAME)],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => 1,
		REDUNDANT_DATA_COUNTERS                   => [
			qw(
			  C66666673
			  C66666674
			  C66666675
			  C67189782
			  C67189783
			  C67189784
			  C67189785
			  C67189786
			  C67189830
			  C67189831
			  C67189832
			  C67189833
			  C67189834
			  C67189835
			  C67189836
			  C67189837
			  C67190391
			  C67190392
			  C67190403
			  C67190567
			  C67190688
			  C67190689
			  C67190690
			  C67190691
			  C67190692
			  C67190693
			  C67190694
			  C67190695
			  C67190696
			  C67190697
			  C67190698
			  C67190699
			  C67190700
			  C67190701
			  C67190702
			  C67190703
			  C67190704
			  C67190705
			  C67191157
			  C67191158
			  C67191159
			  C67191160
			  C67191161
			  C67191162
			  C67191163
			  C67191164
			  C67199637
			  C67199638
			  C67199639
			  C67199640
			  C67199641
			  C67199739
			  C67199740
			  C67199741
			  C67202422
			  C67202423
			  C67202807
			  C67202808
			  C67202894
			  C67202932
			  C67202941
			  )
		],
		PRODUCE_PIF => 'True',

		#OUTPUT_FORMAT		=> 'LIF_Writer',
	},

	#-----------------------------------------------
	# VN BLOCK
	#----------------------------------------------
	{
		RULE_TYPE              => 'JOIN',
		RULE_DESC              => 'Produce VN UtranCellBlock block',
		INPUT_FILE_DESCRIPTION => [
# 			'^II-#-.*67109390(.*)-#-FS-#-S-#-S\.pif$', '^II-#-.*67109372(.*)-#-FS-#-S-#-S\.pif$', '^II-#-.*67109471(.*)-#-FS-#-S-#-S\.pif$', '^II-#-.*67109376(.*)-#-FS-#-S-#-S\.pif$',
# 			'^II-#-.*67109391(.*)-#-FS-#-S-#-S\.pif$', '^II-#-.*67109368(.*)-#-FS-#-S-#-S\.pif$'
			'^II-#-.*67109390(.*)-#-PZ-#-S-#-PZ\.pif$', 
			'^II-#-.*67109372(.*)-#-PZ-#-S-#-PZ\.pif$', 
			'^II-#-.*67109471(.*)-#-PZ-#-S-#-PZ\.pif$', 
			'^II-#-.*67109376(.*)-#-PZ-#-S-#-PZ\.pif$',
			'^II-#-.*67109391(.*)-#-PZ-#-S-#-PZ\.pif$', 
			'^II-#-.*67109368(.*)-#-PZ-#-S-#-PZ\.pif$'			
			
		],
		OUTPUT_BLOCK_NAME       => 'UtranCellBlock',
		REDUNDANT_DATA_COUNTERS => [],
		PRODUCE_PIF             => 0,
		OUTPUT_FORMAT           => 'LIF_Writer',
		COUNTERS_TO_JOIN_ON     => [
			qw(RNC_ID NodeB_Id CELL_ID START_DATE START_TIME)
		],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(FILENAME)],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => 1,
		OUTPUT_FILENAME_START                     => 'UtranCellBlock',
		REDUNDANT_HEADER_COUNTERS                 => [],
	},

	{
		RULE_TYPE               => 'JOIN',
		RULE_DESC               => 'Produce VN cellUpdate block',
		INPUT_FILE_DESCRIPTION  => [ '^II-#-.*67109382(.*)-#-PZ-#-S-#-PZ\.pif$', 
																	'^II-#-.*67109383(.*)-#-PZ-#-S-#-PZ\.pif$', 
																	'^II-#-.*67109384(.*)-#-PZ-#-S-#-PZ\.pif$' ],
		OUTPUT_BLOCK_NAME       => 'cellUpdate',
		REDUNDANT_DATA_COUNTERS => [],
		PRODUCE_PIF             => 0,
		OUTPUT_FORMAT           => 'LIF_Writer',
		COUNTERS_TO_JOIN_ON     => [
			qw(RNC_ID NodeB_Id CELL_ID START_DATE START_TIME)
		],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(FILENAME)],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => 1,
		OUTPUT_FILENAME_START                     => 'cellUpdate',
		REDUNDANT_HEADER_COUNTERS                 => [],
	},

	{
		RULE_TYPE               => 'ACCUMULATE',
		RULE_DESC               => 'Aggregate B67109379 to the RNC level',
		INPUT_FILE_DESCRIPTION  => ['^II-#-.*67109379.*-#-I-#-.*-#-FS-#-S-#-PZ-#-S\.pif$'],
		COUNTERS_TO_SORT_ON     => [qw(START_DATE START_TIME RNC_ID)],
		OUTPUT_BLOCK_NAME       => 'B67109379_GRP',
		REDUNDANT_DATA_COUNTERS => [qw(CELL_ID NodeB_Id)],
		PRODUCE_PIF             => 'True',
		OUTPUT_FORMAT           => 'LIF_Writer',
		NON_ADDITIVE_COUNTERS   => [qw( GP START_DATE Reliability START_TIME)],
		AVERAGE_COUNTERS        => [ 'C67203936', 'C67203937', 'C67203938', 'C67203939', 'C67203940', 'C67203941' ],
		AVERAGE_APPEND_STR      => "_AVG",
		AVERAGE_NO_APPEND_STR   => [ 'C67203936', 'C67203937', 'C67203938', 'C67203939', 'C67203940', 'C67203941' ],
	},

	{
		RULE_TYPE              => 'JOIN',
		RULE_DESC              => 'Produce VN rncMobility block',
		INPUT_FILE_DESCRIPTION => [
			'^II-#-.*67109379(.*)-#-FS-#-S-#-.*-B67109379_GRP-#-A\.pif$', 
			'^.*67109443(.*)-#-FS-#-S-#-PZ\.pif$',
			'^.*67109444(.*)-#-FS-#-S-#-PZ\.pif$',                             
			'^.*67109446(.*)-#-FS-#-S-#-PZ\.pif$',
			'^.*67109447(.*)-#-FS-#-S-#-PZ\.pif$',
		],
		OUTPUT_BLOCK_NAME                         => 'rncMobility',
		REDUNDANT_DATA_COUNTERS                   => [],
		PRODUCE_PIF                               => 0,
		OUTPUT_FORMAT                             => 'LIF_Writer',
		COUNTERS_TO_JOIN_ON                       => [qw(START_DATE START_TIME RNC_ID)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(FILENAME)],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => 1,
		OUTPUT_FILENAME_START                     => 'rncMobility',
		REDUNDANT_HEADER_COUNTERS                 => [],
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Produce VN rncAccessibility block',
		INPUT_FILE_DESCRIPTION                    => [ '^.*67109420(.*)-#-FS-#-S-#-PZ\.pif$', 
																					  '^.*67109422(.*)-#-FS-#-S-#-PZ\.pif$', 
																					  '^.*67109426(.*)-#-FS-#-S-#-PZ\.pif$' ],
		OUTPUT_BLOCK_NAME                         => 'rncAccessibility',
		REDUNDANT_DATA_COUNTERS                   => [],
		PRODUCE_PIF                               => 0,
		OUTPUT_FORMAT                             => 'LIF_Writer',
		COUNTERS_TO_JOIN_ON                       => [qw(START_DATE START_TIME RNC_ID)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(FILENAME)],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => 1,
		OUTPUT_FILENAME_START                     => 'rncAccessibility',
		REDUNDANT_HEADER_COUNTERS                 => [],
	},

	# Aggregate the blocks to RNC leve prior to merging the IU block
	{
		RULE_TYPE               => 'ACCUMULATE',
		RULE_DESC               => 'Agg B67109405 and B67109406 to RNC level for IU block',
		INPUT_FILE_DESCRIPTION  => [ '^.*67109405(.*)-#-FS-#-S-#-PZ\.pif$', 
																	'^.*67109406(.*)-#-FS-#-S-#-PZ\.pif$' ],
		COUNTERS_TO_SORT_ON     => [qw(START_DATE START_TIME RNC_ID)],
		OUTPUT_BLOCK_NAME       => 'IU_AGGR',
		REDUNDANT_DATA_COUNTERS => [qw(IU_INTERFACE_ID OBJECT_ID Reliability)],
		PRODUCE_PIF             => 'True',
		NON_ADDITIVE_COUNTERS   => [qw(START_DATE START_TIME RNC_ID Network_ID Region_ID GP)],
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Produce VN IU block',
		INPUT_FILE_DESCRIPTION                    => [ '^.*67109405(.*)-#-FS-#-S-#-PZ-#-IU_AGGR-#-A\.pif$', 
																					  '^.*67109406(.*)-#-FS-#-S-#-PZ-#-IU_AGGR-#-A\.pif$' ],
		OUTPUT_BLOCK_NAME                         => 'IU',
		REDUNDANT_DATA_COUNTERS                   => [],
		PRODUCE_PIF                               => 0,
		OUTPUT_FORMAT                             => 'LIF_Writer',
		COUNTERS_TO_JOIN_ON                       => [qw(START_DATE START_TIME RNC_ID)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(FILENAME)],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => 1,
		OUTPUT_FILENAME_START                     => 'IU',
		REDUNDANT_HEADER_COUNTERS                 => [],
	},

	#need to do PIF_REMOVE
	{
		RULE_TYPE              => 'PIF_REMOVE',
		RULE_DESC              => 'Remove II input files',
		INPUT_FILE_DESCRIPTION => [
			'^.*67109365.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109366.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109367.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109368.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109369.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109370.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109371.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109372.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109373.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109374.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109375.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109376.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109377.*-#-I-#-.*-#-FS-#-S\.pif$',
			#'^.*67109378.*-#-I-#-.*-#-FS-#-S\.pif$',    #comment for alm00198998
			'^.*67109379.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109380.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109381.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109382.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109383.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109384.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109385.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109386.*-#-I-#-.*-#-FS-#-S\.pif$',
			#'^.*67109387.*-#-I-#-.*-#-FS-#-S\.pif$',    #comment for alm00198998
			'^.*67109387.*-#-I-#-.*-#-FS-#-S-#-S\.pif$',    #add for alm00198998
			'^.*67109388.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109389.*-#-I-#-.*-#-FS-#-S\.pif$',
			#'^.*67109390.*-#-I-#-.*-#-FS-#-S\.pif$',    #comment for alm00198998
			'^.*67109391.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109392.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109393.*-#-I-#-.*-#-FS-#-S\.pif$',        # r10
			'^.*67109471.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109474.*-#-I-#-.*-#-FS-#-S\.pif$',        # r10
			'^.*67109505.*-#-I-#-.*-#-FS-#-S\.pif$',
			#'^.*67109508.*-#-I-#-.*-#-FS-#-S\.pif$',    #comment for alm00198998
			'^.*67109508.*-#-I-#-.*-#-FS-#-S-#-S\.pif$',    # rm the extra pif
			'^.*67109509.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109510.*-#-I-#-.*-#-FS-#-S\.pif$',
			'^.*67109523.*-#-I-#-.*-#-FS-#-S\.pif$',        # r10
		],
	},

	# { #v900r011 - the whole block commented when de-scoped
		# RULE_TYPE              => 'PIF_2_OUTPUT',
		# RULE_DESC              => 'Change blockname into B67109394_V900',
		# INPUT_FILE_DESCRIPTION => ['^.*67109394.*-#-I-#-\d{2}:\d{2}-#-FS-#-V900-#-FS-#-S\.pif'],
		# DEFAULT_NULL_VALUE     => '',
		# OUTPUT_BLOCK_NAME      => 'B67109394_V900',
		# PRODUCE_PIF            => 0,
		# OUTPUT_FORMAT          => 'LIF_Writer',
	# },

	# { #v900r011 - the whole block commented when de-scoped
		# RULE_TYPE              => 'PIF_2_OUTPUT',
		# RULE_DESC              => 'Change blockname into B67109395_V900',
		# INPUT_FILE_DESCRIPTION => ['^.*67109395.*-#-I-#-\d{2}:\d{2}-#-FS-#-V900-#-FS-#-S\.pif'],
		# DEFAULT_NULL_VALUE     => '',
		# OUTPUT_BLOCK_NAME      => 'B67109395_V900',
		# PRODUCE_PIF            => 0,
		# OUTPUT_FORMAT          => 'LIF_Writer',
	# },

	{
		RULE_TYPE              => 'PIF_REMOVE',
		RULE_DESC              => 'Remove 67109549, 67109394, 67109395',
		INPUT_FILE_DESCRIPTION => [
			'^.*67109549.*\.pif$',
			#'^.*67109394.*-#-FS-#-V900-#-FS-#-S\.pif',    #comment for alm00155493, added in v900r011
			#'^.*67109395.*-#-FS-#-V900-#-FS-#-S\.pif',    #comment for alm00155493, added in v900r011
		],
	},

#	{
#		RULE_TYPE              => 'PIF_2_OUTPUT',
#		RULE_DESC              => 'Output ALL LIF files',
#		INPUT_FILE_DESCRIPTION => [
#			'^II-#-.*-#-I-#-.*-#-FS-#-S-#-S\.pif$',
#			'II-#-.*PZ-#-S\.pif$',
#			#'^.*-#-FS-#-S\.pif$',     #comment for alm00198998
#			'^.*(pmresult_|B)(?!67109378|67109387|67109390|67109428|67109508).*-#-FS-#-S.pif$',	#add for alm00198998 only block 67109429 is excluded
#			'^.*82833917.*-#-I-#-\d{2}:\d{2}-#-FS-#-S\.pif$',    #v900r011
#			'^.*82833961.*-#-I-#-\d{2}:\d{2}-#-FS-#-S\.pif$',    #v900r011
#		#	'^.*(82834001|82834002|82834003|82863915|82863925|82863929|67109555|82833952).*-#-I-#-\d{2}\:\d{2}-#-FS\.pif$',
#		],
#		DEFAULT_NULL_VALUE => '',
#		PRODUCE_PIF        => 0,
#		OUTPUT_FORMAT      => 'LIF_Writer',
#	},
	
	#add for alm00198998
	{
		RULE_TYPE              => 'PIF_REMOVE',
		RULE_DESC              => 'Remove II input files after PIF_2_OUTPUT',
		INPUT_FILE_DESCRIPTION => [
			'^.*67109390.*-#-I-#-.*-#-FS-#-S-#-S\.pif$',	#alm00198998 an earlier pif will remain in intermediate folder
		],
	},

	#-------------------------------------------------------------------------------
);

my @rules_no_split_empty = ();

sub postparser_config {	
	return \@rules_no_split;
	#return \@rules_no_split_empty;
}

1;
